;; Generated package description from map.el  -*- no-byte-compile: t -*-
(define-package "map" "3.2.1.0.20220426.133426" "Map manipulation functions" '((emacs "26")) :commit "d35b6a49b33b534f7653bec4d03ab2513a15dc4f" :url "https://elpa.gnu.org/packages/map.html" :authors '(("Nicolas Petton" . "nicolas@petton.fr")) :maintainer '(nil . "emacs-devel@gnu.org") :keywords '("extensions" "lisp"))
